@@ -1,18 +1,18 @@
-cutoff_data <- tibble(
+cutoff_data <- tibble::tibble(
   id = 1:5,
   clinical_pre = c(TRUE, FALSE, FALSE, FALSE, FALSE),
   functional_post = c(TRUE, FALSE, FALSE, TRUE, FALSE)
 )
 
 
-rci_data <- tibble(
+rci_data <- tibble::tibble(
   id = 1:5,
   improved = c(TRUE, TRUE, FALSE, FALSE, FALSE),
   deteriorated = c(FALSE, FALSE, FALSE, TRUE, TRUE),
   unchanged = c(FALSE, FALSE, TRUE, FALSE, FALSE)
 )
 
-ids <- tibble(
+ids <- tibble::tibble(
   id = 1:5,
   rci = "Not needed",
   cs_indiv = "Not needed"
