@@ -28,18 +28,18 @@ test_that("Reliability in HA method is calculated correctly", {
 
 
 # RCI Categories ----------------------------------------------------------
-rci_data <- tibble(id = 1:5, rci = c(-2, -0.5, 0, 0.5, 2))
+rci_data <- tibble::tibble(id = 1:5, rci = c(-2, -0.5, 0, 0.5, 2))
 
-rci_categroies_higher <- rci_data %>%
-  mutate(
+rci_categroies_higher <- rci_data |>
+  dplyr::mutate(
     improved = rci > 1.96,
     deteriorated = rci < -1.96,
     unchanged = !improved & !deteriorated
   )
 
 
-rci_categroies_lower <- rci_data %>%
-  mutate(
+rci_categroies_lower <- rci_data |>
+  dplyr::mutate(
     improved = rci < -1.96,
     deteriorated = rci > 1.96,
     unchanged = !improved & !deteriorated
